California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 031 - STATE BUDGET. STATE AND LOCAL GOVERNMENT. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1333283 | CALIFORNIANS FOR INFORMED VOTING - YES ON 30, 34, 35, 36, 37, AND 39 AND NO ON 31 AND 32 SPONSORED BY BALLOT INITIATIVE STRATEGY CENTER | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1310030 | CALIFORNIANS FOR GOVERNMENT ACCOUNTABILITY - YES ON 31, SPONSORED BY CALIFORNIA FORWARD ACTION FUND | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1348039 | NO ON 31, CALIFORNIANS FOR TRANSPARENT AND ACCOUNTABLE GOVERNMENT | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1344386 | YES ON 31, TAXPAYERS FOR GOVT. ACCOUNTABILITY, MAJOR FUNDING BY BERGGRUEN INSTITUTE TRUST & CALIFORNIANS FOR GOVT. ACCOUNTABILITY CMTE., SPON. BY CA FORWARD ACTION FUND & THINK LONG COMMITTEE FOR CA | SUPPORT